@@ -257,29 +257,10 @@ window_destroy_cb (GtkWidget *window,
 	GnomeCD *gcd = data;
 
 	/* Before killing the cdrom object, do the shutdown on it */
-	switch (gcd->preferences->stop) {
-	case GNOME_CD_PREFERENCES_STOP_NOTHING:
-		break;
-
-	case GNOME_CD_PREFERENCES_STOP_STOP:
-		gnome_cdrom_stop (gcd->cdrom, NULL);
-		break;
-
-	case GNOME_CD_PREFERENCES_STOP_OPEN:
+	if (gcd->preferences->stop_eject) {
 		gnome_cdrom_eject (gcd->cdrom, NULL);
-		break;
-		
-#ifdef HAVE_CDROMCLOSETRAY_IOCTL
-	case GNOME_CD_PREFERENCES_STOP_CLOSE:
-		gnome_cdrom_close_tray (gcd->cdrom, NULL);
-		break;
-#endif
-
-	default:
-		g_assert_not_reached ();
-		break;
 	}
-
+		
 	/* Unref the cddb slave */
 	cddb_close_client ();
 
@@ -650,7 +631,7 @@ init_player (const char *device_override)
 	gcd->tray_icon = gtk_image_new_from_pixbuf (pixbuf);
 	gtk_container_add (GTK_CONTAINER (box), gcd->tray_icon);
 	gcd->tray_tips = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (gcd->tray_tips, gcd->tray, _("CD Player"), NULL);
+	gtk_tooltips_set_tip (GTK_TOOLTIPS(gcd->tray_tips), gcd->tray, _("CD Player"), NULL);
 	gnome_popup_menu_attach (make_popup_menu (gcd), box, NULL);
 	gtk_widget_show_all (gcd->tray);
 
@@ -726,16 +707,12 @@ register_stock_icons (void)
 	g_object_unref (G_OBJECT (factory));
 }
 
-static const struct poptOption cd_popt_options [] = {
-	{ "device", '\0', POPT_ARG_STRING, &cd_option_device, 0,
-	  N_("CD device to use"), NULL },
-	{ NULL, '\0', 0, NULL, 0 },
-};
-
 int 
 main (int argc, char *argv[])
 {
 	static const struct poptOption cd_popt_options [] = {
+		{ "device", '\0', POPT_ARG_STRING, &cd_option_device, 0,
+		  N_("CD device to use"), NULL },
 		{ "unique", '\0', POPT_ARG_NONE, &cd_option_unique, 0,
 		  N_("Only start if there isn't already a CD player application running"), NULL },
 		{ "play",   '\0', POPT_ARG_NONE, &cd_option_play, 0,
@@ -744,7 +721,6 @@ main (int argc, char *argv[])
 	};
 
 	GnomeCD *gcd;
-	CDSelection *cd_selection;
 	GnomeClient *client;
 
 	free (malloc (8)); /* -lefence */
@@ -778,33 +754,9 @@ main (int argc, char *argv[])
 	g_signal_connect (client, "die",
 			  G_CALLBACK (client_die), gcd);
 
-	/* Do the start up stuff */
-#ifdef HAVE_CDROMCLOSETRAY_IOCTL
-	if (gcd->preferences->start_close) {
-		gnome_cdrom_close_tray (gcd->cdrom, NULL);
-	}
-#endif
-
-	if (cd_option_play) {
+	if (cd_option_play || gcd->preferences->start_play) {
 		/* Just fake a click on the button */
 		play_cb (NULL, gcd);
-	} else {
-	switch (gcd->preferences->start) {
-	case GNOME_CD_PREFERENCES_START_NOTHING:
-		break;
-
-	case GNOME_CD_PREFERENCES_START_START:
-		/* Just fake a click on the button */
-		play_cb (NULL, gcd);
-		break;
-		
-	case GNOME_CD_PREFERENCES_START_STOP:
-		gnome_cdrom_stop (gcd->cdrom, NULL);
-		break;
-
-	default:
-		break;
-	}
 	}
 	
 	if (cd_option_unique &&
